@@ -4,7 +4,7 @@
  * Implementation for pre-WinXP getaddrinfo() and getnameinfo() APIs.
  *
  *
- * $Id: wspiapi.h,v 0e6af670539f 2020/01/20 18:03:57 keith $
+ * $Id: wspiapi.h,v 0765242a471d 2020/07/05 21:32:09 keith $
  *
  * Written by Keith Marshall <keith@users.osdn.me>
  * Copyright (C) 2020, MinGW.org Project
@@ -914,7 +914,7 @@ WSAAPI int __wspiapi_getnameinfo
    * Microsoft's invalid parameter handler, while reporting it as an
    * EAI_SYSTEM exception.
    */
-  if( (sa == NULL) || (len < sizeof( struct sockaddr )) )
+  if( (sa == NULL) || (len < (socklen_t)(sizeof( struct sockaddr ))) )
     return __wspiapi_syserrout( EINVAL );
 
   { /* When the "sa" argument is valid, we delegate the call to the
